@@ -14,6 +14,9 @@ class HomeScreen;
 class FolioSettings : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("")
+
     Q_PROPERTY(int homeScreenRows READ homeScreenRows WRITE setHomeScreenRows NOTIFY homeScreenRowsChanged)
     Q_PROPERTY(int homeScreenColumns READ homeScreenColumns WRITE setHomeScreenColumns NOTIFY homeScreenColumnsChanged)
     Q_PROPERTY(bool showPagesAppLabels READ showPagesAppLabels WRITE setShowPagesAppLabels NOTIFY showPagesAppLabelsChanged)
@@ -23,7 +26,8 @@ class FolioSettings : public QObject
     Q_PROPERTY(bool showFavouritesBarBackground READ showFavouritesBarBackground WRITE setShowFavouritesBarBackground NOTIFY showFavouritesBarBackgroundChanged)
     Q_PROPERTY(
         FolioSettings::PageTransitionEffect pageTransitionEffect READ pageTransitionEffect WRITE setPageTransitionEffect NOTIFY pageTransitionEffectChanged)
-    Q_PROPERTY(bool showWallpaperBlur READ showWallpaperBlur WRITE setShowWallpaperBlur NOTIFY showWallpaperBlurChanged)
+    Q_PROPERTY(FolioSettings::WallpaperBlurEffect wallpaperBlurEffect READ wallpaperBlurEffect WRITE setWallpaperBlurEffect NOTIFY wallpaperBlurEffectChanged)
+    Q_PROPERTY(bool doubleTapToLock READ doubleTapToLock WRITE setDoubleTapToLock NOTIFY doubleTapToLockChanged)
 
 public:
     FolioSettings(HomeScreen *parent = nullptr);
@@ -38,6 +42,21 @@ public:
     };
     Q_ENUM(PageTransitionEffect)
 
+    enum WallpaperBlurEffect {
+        None = 0,
+        Simple = 1,
+        Full = 2,
+    };
+    Q_ENUM(WallpaperBlurEffect)
+
+    // JSON object
+    QString favorites() const;
+    void setFavorites(const QString &favoritesJson);
+
+    // JSON object
+    QString pages() const;
+    void setPages(const QString &pagesJson);
+
     // number of rows and columns in the config for the homescreen
     // NOTE: use HomeScreenState.pageRows() instead in UI logic since we may have the rows and
     //       columns swapped (in landscape layouts)
@@ -65,8 +84,11 @@ public:
     PageTransitionEffect pageTransitionEffect() const;
     void setPageTransitionEffect(PageTransitionEffect pageTransitionEffect);
 
-    bool showWallpaperBlur() const;
-    void setShowWallpaperBlur(bool showWallpaperBlur);
+    WallpaperBlurEffect wallpaperBlurEffect() const;
+    void setWallpaperBlurEffect(WallpaperBlurEffect wallpaperBlurEffect);
+
+    bool doubleTapToLock() const;
+    void setDoubleTapToLock(bool doubleTapToLock);
 
     Q_INVOKABLE void load();
 
@@ -82,10 +104,15 @@ Q_SIGNALS:
     void delegateIconSizeChanged();
     void showFavouritesBarBackgroundChanged();
     void pageTransitionEffectChanged();
-    void showWallpaperBlurChanged();
+    void wallpaperBlurEffectChanged();
+    void doubleTapToLockChanged();
 
 private:
     void save();
+    KConfigGroup generalConfigGroup() const;
+
+    // Legacy
+    void migrateConfigFromPlasma6_4();
 
     HomeScreen *m_homeScreen{nullptr};
 
@@ -97,5 +124,6 @@ private:
     qreal m_delegateIconSize{48};
     bool m_showFavouritesBarBackground{false};
     PageTransitionEffect m_pageTransitionEffect{SlideTransition};
-    bool m_showWallpaperBlur{false};
+    WallpaperBlurEffect m_wallpaperBlurEffect{Full};
+    bool m_doubleTapToLock{false};
 };
